using System;
using System.Linq;

/// @Miika Zitting 
/// @version 07.12.2023
/// <summary>
/// This application prints out daily temperature avergae, min, max.
/// Original plan was to grab daily weather data from an open API, but no suitable API was found for this project.
/// </summary>
/// 
public class Ohj1Ht
{
    /// <summary>
    /// Prints out the average, max and min temperatures for the dataset.
    /// </summary>
    public static void Main()
    {
        string city = "Espoo";
        string filePath = @"/Users/xxx/ohj1ht/temps.json";
        double[] temps = ReadTempsFromJson(filePath);
        if (temps == null)
        {
            Console.WriteLine("ERROR: Error in dataset, no values found");
        }
        else
        {
            double avg = CalculateAverage(temps);
            double maxTemp = temps.Max();
            double minTemp = temps.Min();
            Console.WriteLine("Average for temperatures in "+city+" for tomorrow is: "+avg+" celsius. With highest tempererature of " + maxTemp + " and lowest of " + minTemp +" celsius");
        }
    }


    /// <summary>
    /// Function should grab hourly temperature data for a day, from json file / API. Now array in simulated straight into variable temps.
    /// </summary>
    /// <param name="filePath">Path for the json file, that contains temperature measurement data</param>
    /// <returns>
    /// Returns an array "temps", containing measurement data
    /// </returns>
    private static double[] ReadTempsFromJson(string filePath)
    {
        double[] temps = {11.2, 12.0, 13.0, 11.5, 11.0, 10.8, 10.6, 9.9, 9.7, 9.2, 6.0, 5.0, 4.0, 5.1, 5.5, 7.1, 8.0, 8.2, 8.8, 8.9, 9.5, 10.2, 10.5, 11.9};
        if (temps.Length <= 24 && temps.Length > 0)
        {
            return temps;
        }
        else
        {
            Console.WriteLine("Problem occured in dataset. Daily measurements cannot be 0 or contain over 24 values.");
            return null;
        }
    }
    
    
    /// <summary>
    /// Calculates the average temperature for the provided dataset 
    /// </summary>
    /// <param name="temps">Array containing measurement data</param>
    /// <returns>
    /// Returns average temperature value based on the array data points.
    /// </returns>
    /// <example>
    /// <pre name="test">
    /// 	double[] tempsTest = new double[] {11.2, 10.0, 13.0, 9.5, 11.0, 10.8, 10.6, 9.9, 9.7, 9.2, 6.0, 5.0, 4.0, 5.1, 5.5, 7.1, 8.0, 8.2, 8.8, 10.9, 9.5, 10.2, 10.5, 11.9};
    /// 	double[] tempsTest2 = new double[] {11.2};
    /// 	double[] tempsTest3 = new double[] {5.0, 6.0, 7.0, 100.0};
    /// 	double[] tempsTest4 = new double[] {};
    /// 	CalculateAverage(tempsTest) === 9;
    /// 	CalculateAverage(tempsTest2) === 11.2;
    ///     CalculateAverage(tempsTest3) === 29.5;
    ///     CalculateAverage(tempsTest4) === int.MinValue;
    /// </pre>
    /// </example>
    private static double CalculateAverage(double[] temps)
    {
        double sum = 0;
        double avg = 0;
        int count = temps.Length;

        if (count == 0)
        {
            return int.MinValue;
        }
        
        if (count == 24)
        {
            for (int i = 0; i < count; i++)
            {
                sum = sum + temps[i];
            }

            avg = sum / count;
        }

        if (count < 24)
        {
            for (int i = 0; i < count; i++)
            {
                sum = sum + temps[i];
            }
            avg = sum / count;
            Console.WriteLine("Average cannot be calculated accurately with "+count+" values. 24 measurements are required.");
        }

        return Math.Round(avg, 1);
    }
}